"""Base API class for EShopBox SDK"""

import requests
from typing import Dict, Optional, Any
from eshopbox.auth import EShopBoxAuth
from eshopbox.exceptions import APIError, RateLimitError, NotFoundError


class BaseAPI:
    """Base class for all API modules"""

    def __init__(self, workspace: str, auth: EShopBoxAuth):
        """
        Initialize base API

        Args:
            workspace: EShopBox workspace name
            auth: Authentication handler
        """
        self.workspace = workspace
        self.auth = auth
        self.base_url = f"https://{workspace}.myeshopbox.com"
        self.eshopbox_url = f"https://{workspace}.eshopbox.com"

    def _make_request(
        self,
        method: str,
        url: str,
        params: Optional[Dict] = None,
        json: Optional[Dict] = None,
        **kwargs
    ) -> Any:
        """
        Make HTTP request with authentication and error handling

        Args:
            method: HTTP method (GET, POST, PUT, DELETE)
            url: Request URL
            params: Query parameters
            json: JSON body
            **kwargs: Additional request arguments

        Returns:
            Response data

        Raises:
            APIError: If API returns an error
            RateLimitError: If rate limit is exceeded
            NotFoundError: If resource is not found
        """
        headers = self.auth.get_headers()
        if 'headers' in kwargs:
            headers.update(kwargs['headers'])
        kwargs['headers'] = headers

        if params:
            kwargs['params'] = params
        if json:
            kwargs['json'] = json

        try:
            response = requests.request(method, url, **kwargs)

            # Handle different status codes
            if response.status_code == 404:
                raise NotFoundError(f"Resource not found: {url}")
            elif response.status_code == 429:
                raise RateLimitError("Rate limit exceeded. Please try again later.")
            elif response.status_code >= 400:
                error_msg = self._extract_error_message(response)
                raise APIError(
                    error_msg,
                    status_code=response.status_code,
                    response=response.text
                )

            response.raise_for_status()

            # Return JSON if content exists, otherwise empty dict
            return response.json() if response.content else {}

        except requests.RequestException as e:
            if isinstance(e, (APIError, RateLimitError, NotFoundError)):
                raise
            raise APIError(f"Request failed: {str(e)}")

    def _extract_error_message(self, response: requests.Response) -> str:
        """Extract error message from response"""
        try:
            error_data = response.json()
            return error_data.get('message', error_data.get('error', response.text))
        except:
            return response.text or f"HTTP {response.status_code} Error"



"""
Example: Setup Settings using EShopBox SDK
"""

from eshopbox import EShopBoxSDK
import os
from dotenv import load_dotenv
load_dotenv()


def get_portals(sdk):
    response = sdk.settings.get_portals()
    print(response)


def create_workspace(sdk):
    data = {
        "data": {
            "accountSlug": "eshop",
            "accountName": "Eshopbox"
        }
    }
    response = sdk.settings.create_workspace(data)
    print(response)


def get_all_workspace(sdk):
    params = {
        "page": 1,
        "limit": 10
    }
    response = sdk.settings.get_all_workspace(params)
    print(response)


def get_workspace(sdk):
    response = sdk.settings.get_workspace()
    print(response)


def update_workspace(sdk):
    data = {
        "data": {
            "accountSlug": "eshop",
            "accountName": "XXXXXXXX"
        }
    }
    response = sdk.settings.update_workspace(data)
    print(response)


def create_sales_channel(sdk):
    data = {
        "data": {
            "portalId": 1,
            "integrationModelId": 1,
            "channelAccountId": 1,
            "fulfillmentChannels": [
                {
                    "warehouseId": 1
                },
                {
                    "warehouseId": 2
                }
            ]
        }
    }
    response = sdk.settings.create_sales_channel(data)
    print(response)


def update_sales_channel(sdk):
    data = {
        "data": {
            "portalId": 1,
            "integrationModelId": 1,
            "channelAccountId": 1,
            "fulfillmentChannels": [
                {
                    "warehouseId": 1
                },
                {
                    "warehouseId": 2
                }
            ]
        }
    }
    response = sdk.settings.update_sales_channel(1, data)
    print(response)


def get_all_sales_channel(sdk):
    response = sdk.settings.get_all_sales_channel()
    print(response)


def get_sales_channel(sdk):
    response = sdk.settings.get_sales_channel(4801)
    print(response)


def create_fc_submission(sdk):
    data = {
        "data": {
            "warehouseId": "1",
            "warehouseName": "TCNS Banglore",
            "externalWmsAccountId": "1",
            "facility": "BDBLR108",
            "operatingModel": "consignment",
            "requestDocuments": {
                "gstCertificateUrl": "http://abc.com/1.jpg",
                "signatureUrl": "http://abc.com/2.jpg",
                "companyLogoUrl": "http://abc.com/3.jpg"
            }
        }
    }
    response = sdk.settings.create_fc_submission(data)
    print(response)


def get_all_fc_submission(sdk):
    response = sdk.settings.get_all_fc_submission()
    print(response)


def get_fc_submission(sdk):
    response = sdk.settings.get_fc_submission(1)
    print(response)


def create_contact(sdk):
    data = {
        "data": {
            "contactCode": "1234",
            "contactName": "ABC",
            "contactEmail": "XXXXXXXXXXXXX",
            "contactPhone": "1234567890",
            "contactType": "seller",
            "contactAddress": "ABC"
        }
    }
    response = sdk.settings.create_contact(data)
    print(response)


def update_fc_submission(sdk):
    data = {
        "data": {
            "warehouseId": "1",
            "warehouseName": "TCNS Banglore",
            "externalWmsAccountId": "1",
            "facility": "BDBLR108",
            "operatingModel": "consignment",
            "requestDocuments": {
                "gstCertificateUrl": "XXXXXXXXXXXXXXXXXXXX",
                "signatureUrl": "XXXXXXXXXXXXXXXXXXXX",
                "companyLogoUrl": "XXXXXXXXXXXXXXXXXXXX"
            }
        }
    }
    response = sdk.settings.update_fc_submission(1, data)
    print(response)


def get_all_contact(sdk):
    response = sdk.settings.get_all_contact()
    print(response)


def get_contact(sdk):
    params = {
        "contactCode": "1234"
    }
    response = sdk.settings.get_contact(params)
    print(response)


def update_contact(sdk):
    data = {
        "data": {
            "contactCode": "1234",
            "contactName": "ABC",
            "contactEmail": "XXXXXXXXXXXXX",
            "contactPhone": "1234567890",
            "contactType": "seller",
            "contactAddress": "ABC"
        }
    }
    response = sdk.settings.update_contact("1234", data)
    print(response)


def create_team_member(sdk):
    data = {
        "data": {
            "userId": 1,
            "portalId": 1,
            "integrationModelId": 1,
            "channelAccountId": 1,
            "warehouseId": 1
        }
    }
    response = sdk.settings.create_team_member(data)
    print(response)


def update_team_member(sdk):
    data = {
        "data": {
            "userId": 1,
            "portalId": 1,
            "integrationModelId": 1,
            "channelAccountId": 1,
            "warehouseId": 1
        }
    }
    response = sdk.settings.update_team_member(1, data)
    print(response)


def get_team_member(sdk):
    response = sdk.settings.get_team_member(1)
    print(response)


def get_all_team_member(sdk):
    response = sdk.settings.get_all_team_member()
    print(response)


def main():
    # Initialize SDK
    sdk = EShopBoxSDK(
        workspace=os.getenv('ESHOPBOX_WORKSPACE', ''),
        client_id=os.getenv('ESHOPBOX_CLIENT_ID', ''),
        client_secret=os.getenv('ESHOPBOX_SECRET_ID', ''),
        refresh_token=os.getenv('ESHOPBOX_REFRESH_TOKEN', '')
    )

    # get_portals(sdk)
    # create_workspace(sdk)
    # get_all_workspace(sdk)
    # get_workspace(sdk)
    # update_workspace(sdk)
    # create_sales_channel(sdk)
    # update_sales_channel(sdk)
    # get_all_sales_channel(sdk)
    # get_sales_channel(sdk)
    # create_fc_submission(sdk)
    # get_all_fc_submission(sdk)
    # get_fc_submission(sdk)
    # update_fc_submission(sdk)
    # create_contact(sdk)
    # get_all_contact(sdk)
    # get_contact(sdk)
    # update_contact(sdk)
    # create_team_member(sdk)
    # update_team_member(sdk)
    # get_team_member(sdk)
    get_all_team_member(sdk)


if __name__ == "__main__":
    main()



"""
Example: Track shipment using EShopBox SDK
"""

from eshopbox import EShopBoxSDK
import os
from dotenv import load_dotenv
load_dotenv()


def create_label_and_awb(sdk):
    payload = {
        "boxHeight": 2,
        "boxLength": 2,
        "boxWidth": 2,
        "weight": 2,
        "orderItems": [
            {
                "orderItemId": "49252941",
                "invoiceNumber": "string",
                "invoiceDate": "2017-01-02T08:12:53",
                "taxRate": 0,
                "centralGstPercentage": 0,
                "compensationCessPercentage": 0,
                "integratedGstPercentage": 0,
                "stateGstPercentage": 0,
                "unionTerritoryGstPercentage": 0
            }
        ]
    }
    order_status_update = sdk.order_status_update.create_label_and_awb(payload)
    print(order_status_update)


def get_awb_and_courier_name(sdk):
    params = {
        "orderItemIds": "49252941,49252802"
    }
    order_status_update = sdk.order_status_update.get_awb_and_courier_name(params)
    print(order_status_update)


def dispatch_shipment(sdk):
    payload = {
        "orderItems": [
            {
                "orderItemId": "49252941",
                "quantity": 1,
                "centralGstPercentage": 0,
                "compensationCessPercentage": 0,
                "integratedGstPercentage": 0,
                "stateGstPercentage": 0,
                "taxRate": 0,
                "unionTerritoryGstPercentage": 0
            }
        ],
        "selfShipping": {
            "deliveryPartner": "ecomExpress",
            "dispatchDate": "2017-01-02T08:12:53",
            "invoiceDate": "2017-01-02T08:12:53",
            "invoiceNumber": "string",
            "tentativeDeliveryDate": "2017-01-02T08:12:53",
            "trackingId": "123455"
        }
    }
    order_status_update = sdk.order_status_update.dispatch_shipment(payload)
    print(order_status_update)


def courier_details_for_return(sdk):
    order_status_update = sdk.order_status_update.courier_details_for_return("R2113455")
    print(order_status_update)


def update(sdk):
    payload = {
        "status_description": "Delivered",
        "waybill": "1704610028453",
        "cp_name": "Delhivery",
        "status": "Delivered",
        "status_code": 8,
        "location": "GGN_DPC (Haryana)",
        "additional": {
            "latest_status": {
                "status_description": "Delivered",
                "remark": "Added to IST",
                "status": "In Transit",
                "status_code": 8,
                "location": "GGN_DPC (Haryana)",
                "timestamp": "2018-07-12T12:58:40.910000Z"
            }
        },
        "timestamp": "2018-07-12T11:53:39.902000Z",
        "remark": "Bagged at destination city PC"
    }
    order_status_update = sdk.order_status_update.update(payload)
    print(order_status_update)


def main():
    sdk = EShopBoxSDK(
        workspace=os.getenv('ESHOPBOX_WORKSPACE', ''),
        client_id=os.getenv('ESHOPBOX_CLIENT_ID', ''),
        client_secret=os.getenv('ESHOPBOX_SECRET_ID', ''),
        refresh_token=os.getenv('ESHOPBOX_REFRESH_TOKEN', '')
    )

    # create_label_and_awb(sdk)
    # get_awb_and_courier_name(sdk)
    # dispatch_shipment(sdk)
    # courier_details_for_return(sdk)
    update(sdk)


if __name__ == "__main__":
    main()



"""Products API module"""

from typing import Dict
from eshopbox.api.base import BaseAPI


class ProductsAPI(BaseAPI):
    """Handle product-related operations"""

    def get_all(self, params) -> Dict:
        """Fetch all products with optional filters."""
        url = f"{self.base_url}/product-engine/api/v1/products"
        return self._make_request("GET", url, params=params)

    def get(self, sku: str) -> Dict:
        """Fetch a single product by SKU."""
        url = f"{self.base_url}/product-engine/api/v1/products/{sku}"
        return self._make_request("GET", url)

    def create(self, product_data: Dict) -> Dict:
        """Create a new product."""
        url = f"{self.base_url}/product-engine/api/v1/products"
        return self._make_request("POST", url, json=product_data)

    def update(self, sku: str, product_data: Dict) -> Dict:
        """Update an existing product."""
        url = f"{self.base_url}/product-engine/api/v1/products/{sku}"
        return self._make_request("PUT", url, json=product_data)

    def delete(self, sku: str) -> Dict:
        """Update an existing product."""
        url = f"{self.base_url}/product-engine/api/v1/products/{sku}"
        return self._make_request("DELETE", url)

    def merge_product(self, product_data: Dict) -> Dict:
        """Update an existing product."""
        url = f"{self.base_url}/product-engine/api/v1/mergeProducts"
        return self._make_request("POST", url, json=product_data)

    def product_availability(self, product_data: Dict) -> Dict:
        """Update an existing product."""
        url = f"{self.base_url}/product-engine/api/v2/productListing"
        return self._make_request("POST", url, json=product_data)

    def get_all_brands(self) -> Dict:
        """Update an existing product."""
        url = f"{self.base_url}/api/v1/brand"
        return self._make_request("GET", url)

    def get_brand(self, id: int) -> Dict:
        """Update an existing product."""
        url = f"{self.base_url}/api/v1/brand"
        params = {
            "id": id
        }
        return self._make_request("GET", url, params=params)

    def create_brand(self, product_data: Dict) -> Dict:
        """Update an existing product."""
        url = f"{self.base_url}/api/v1/brand"
        return self._make_request("POST", url, json=product_data)

    def update_brand(self, id, product_data: Dict) -> Dict:
        """Update an existing product."""
        url = f"{self.base_url}/api/v1/brand/{id}"
        return self._make_request("PUT", url, json=product_data)

    def get_inventory_for_given_product_v1(self, product_data: Dict) -> Dict:
        """Update an existing product."""
        url = f"{self.base_url}/api/v1/productListing"
        return self._make_request("POST", url, json=product_data)

    def get_inventory_for_given_product_v2(self, params: Dict) -> Dict:
        """Update an existing product."""
        url = f"{self.base_url}/api/v2/productListing"
        return self._make_request("GET", url, params=params)

    def get_inventory_summary(self, params: Dict) -> Dict:
        """Update an existing product."""
        url = f"{self.base_url}/api/v1/productListing"
        return self._make_request("GET", url, params=params)



import os
import sys
from datetime import datetime

# Add project root
sys.path.insert(0, os.path.abspath("../"))

project = "EShopBox SDK"
author = "Kashwork Technologies"
year = datetime.now().year
copyright = f"{year}, {author}"

extensions = [
    "sphinx.ext.autodoc",
    "sphinx.ext.napoleon",
    "sphinx.ext.viewcode",
    "sphinx.ext.autosummary",
]

autodoc_default_options = {
    "members": True,
    "undoc-members": False,
    "show-inheritance": True,
}

templates_path = ["_templates"]
exclude_patterns = []

html_theme = "sphinx_rtd_theme"
html_static_path = ["_static"]



"""
Example: Setup Rate Calculator using EShopBox SDK
"""

import os
from eshopbox.client import EShopBoxSDK
from dotenv import load_dotenv
load_dotenv()


def rate_calculator(sdk):
    payload = {
        "journeyType": "forward",
        "pickupPincode": "160071",
        "dropPincode": "247342",
        "orderWeight": "500",
        "length": "12",
        "width": "12",
        "height": "33",
        "paymentMethod": "Prepaid",
        "doorstepQc": False
    }
    response = sdk.rate_calculator.calculate(payload)
    print("Response: ", response)


def main():
    sdk = EShopBoxSDK(
        workspace=os.getenv('ESHOPBOX_WORKSPACE', ''),
        client_id=os.getenv('ESHOPBOX_CLIENT_ID', ''),
        client_secret=os.getenv('ESHOPBOX_SECRET_ID', ''),
        refresh_token=os.getenv('ESHOPBOX_REFRESH_TOKEN', '')
    )
    rate_calculator(sdk)


if __name__ == "__main__":
    main()



"""Webhooks API module"""

from typing import Dict
from eshopbox.api.base import BaseAPI


class WebhooksAPI(BaseAPI):
    """Manage webhooks"""

    def list(self) -> Dict:
        """List all registered webhooks."""
        url = f"{self.base_url}/api/platform/v1/client-webhook"
        return self._make_request("GET", url)

    def create(self, webhook_data: Dict) -> Dict:
        """Create a webhook."""
        url = f"{self.base_url}/api/v1/webhook"
        return self._make_request("POST", url, json=webhook_data)

    def get(self, webhook_id: str) -> Dict:
        """Delete a webhook."""
        url = f"{self.base_url}/api/platform/v1/client-webhook/{webhook_id}"
        return self._make_request("GET", url)

    def update(self, webhook_id: str) -> Dict:
        """Delete a webhook."""
        url = f"{self.base_url}/api/platform/v1/client-webhook"
        return self._make_request("PUT", url)



import pytest
from eshopbox import EShopBoxSDK


@pytest.fixture
def sdk():
    return EShopBoxSDK(
        workspace="test",
        client_id="test_id",
        client_secret="test_secret",
        refresh_token="test_refresh_token",
    )


@pytest.fixture
def mock_token(requests_mock):
    """Mocks auth token request."""
    requests_mock.post(
        "https://auth.myeshopbox.com/api/v1/generateToken",
        json={"access_token": "mock_access_token"}
    )



"""Order model"""

from typing import Optional, List
from pydantic import BaseModel, Field

from eshopbox.models.address import Address
from eshopbox.models.product import Product


class OrderItem(BaseModel):
    """Represents an item inside an order."""

    sku: str = Field(..., description="Product SKU")
    name: Optional[str] = Field(None)
    quantity: int = Field(..., ge=1, description="Quantity ordered")
    price: float = Field(..., ge=0, description="Unit price")


class PaymentInfo(BaseModel):
    """Order payment details"""

    method: str = Field(..., description="Payment method e.g. COD, Prepaid")
    transaction_id: Optional[str] = Field(None, description="Payment transaction ID")
    amount: float = Field(..., ge=0, description="Paid amount")


class Order(BaseModel):
    """Represents an order."""

    customer_order_number: str = Field(..., description="Unique external customer order number")
    channel_id: str = Field(..., description="Channel identifier")

    shipping_address: Address
    billing_address: Optional[Address] = None

    items: List[OrderItem] = Field(..., description="Order item list")
    payment: Optional[PaymentInfo] = Field(None, description="Payment details")

    order_date: Optional[str] = Field(None, description="Order timestamp")
    status: Optional[str] = Field(None, description="Order status")



"""Serviceability API module"""

from typing import Dict
from eshopbox.api.base import BaseAPI


class ServiceabilityAPI(BaseAPI):
    """Check whether a PIN code or region is serviceable"""

    def pincodeserviceability(self, payload: Dict) -> Dict:
        """Get serviceability based on drop pincode, pickup pincode and product dimension."""
        url = f"{self.base_url}/api/v2/pincodeserviceability"
        return self._make_request("POST", url, json=payload)

    def productserviceability(self, payload: Dict) -> Dict:
        """Get Serviciability for Drop pincode and product sku."""
        url = f"{self.base_url}/api/v2/check/product/serviceability"
        return self._make_request("POST", url, json=payload)

    def checkpincodeserviceability(self, payload: Dict) -> Dict:
        """Get serviceability for pickup and drop pincode."""
        url = f"{self.base_url}/api/v1/checkpincodeserviceability"
        return self._make_request("POST", url, json=payload)

    def bulkPincodeServiceability(self, params: Dict) -> Dict:
        """Get Bulk Pincode Serviceability."""
        url = f"{self.base_url}/shipping-wms/api/v1/bulkPincodeServiceability"
        return self._make_request("GET", url, params=params)



"""Version information for EShopBox SDK"""

__version__ = '1.1.4'
__author__ = 'Sakib Mailk'
__email__ = 'sakibwis.wis@gmail.com'
__license__ = 'MIT'
__description__ = 'Python SDK for EShopBox Shipping APIs'
__url__ = 'https://github.com/sakib-wis/eshopbox-sdk'



"""
Example: Setup Payment using EShopBox SDK
"""

from eshopbox import EShopBoxSDK
import os
from dotenv import load_dotenv
load_dotenv()


def get_payouts(sdk):
    response = sdk.payments.get_payouts()
    print(response)


def get_payout(sdk):
    params = {
        "neftId": "neftId"
    }
    response = sdk.payments.get_payout(params)
    print(response)


def create_payout(sdk):
    payload = {
        "fundTransferDate": "2018-09-25 05:30:00",
        "fundTransferAmount": 819901.7199999853,
        "transactionId": "lime3",
        "comments": "Limeroad Testing",
        "ledgerGroupId": "limeroad",
        "portalAccountId": 122,
        "reportUrl": "https://cdn.filestackcontent.com/ckdksjkasl676678687as"
    }
    response = sdk.payments.create_payout(payload)
    print(response)


def update_fee(sdk):
    payload = {
        "portalId": 3,
        "feeId": "40",
        "feeName": None,
        "isInclusiveTax": "0",
        "inclusiveTaxPercentage": "63",
        "chargedFee": "cancelled",
        "chargedFeeCases": "",
        "courierReturnedFee": "",
        "courierReturnedPercent": "",
        "customerReturnedFee": "",
        "customerReturnedPercent": "",
        "validityPeriod": "definite",
        "validFrom": "2019-09-09",
        "validTo": "2019-09-11",
        "fee": [
            {
                "eventType": "shipped",
                "eventSubType": "",
                "partialPercentageValue": "",
                "feeCharged": "CHARGED_FEE"
            },
            {
                "eventType": "returned",
                "eventSubType": "courier",
                "partialPercentageValue": "",
                "feeCharged": "REVERSED_FEE"
            },
            {
                "eventType": "returned",
                "eventSubType": "customer",
                "partialPercentageValue": "",
                "feeCharged": "REVERSED_FEE"
            }
        ],
        "feeRules": [
            {
                "details": {
                    "shippingZone": "regional"
                },
                "feeValues": [
                    {
                        "type": "fixed",
                        "value": 2,
                        "applicableOn": "Per Order",
                        "id": 1
                    }
                ]
            }
        ],
        "id": 603,
        "ruleId": "5d7a4867ad0cf20001e527df",
        "forRevision": True
    }
    response = sdk.payments.update_fee(payload)
    print(response)


def create_fee(sdk):
    payload = {
        "portalId": 2,
        "feeId": "1",
        "feeName": "",
        "isInclusiveTax": "0",
        "inclusiveTaxPercentage": "11",
        "chargedFee": "cancelled",
        "chargedFeeCases": "",
        "courierReturnedFee": "",
        "courierReturnedPercent": "",
        "customerReturnedFee": "",
        "customerReturnedPercent": "",
        "fee": [
            {
                "eventType": "cancelled",
                "eventSubType": "",
                "feeCharged": "CHARGED_FEE"
            }
        ],
        "feeRules": [
            {
                "details": {},
                "feeRanges": [
                    {
                        "rangeType": "product selling price",
                        "rangeTypeUnit": "INR",
                        "minRange": 0,
                        "maxRange": 100
                    }
                ],
                "feeValues": [
                    {
                        "type": "fixed",
                        "partitionRangeType": None,
                        "value": 12,
                        "applicableOn": "Per Order",
                        "partitionRange": None
                    }
                ]
            }
        ],
        "validFrom": "2019-09-01T00:00:00.000Z",
        "feePortalId": "145",
        "validityPeriod": "definite",
        "ruleId": "5d7f2b78ad0cf200017cebbb"
    }
    response = sdk.payments.create_fee(payload)
    print(response)


def get_all_fee(sdk):
    response = sdk.payments.get_all_fee()
    print(response)


def get_fee(sdk):
    params = {
        "feeName": "amazon",
    }
    response = sdk.payments.get_fee(params)
    print(response)


def get_all_transaction_rules(sdk):
    response = sdk.payments.get_all_transaction_rules()
    print(response)


def get_transaction_rule(sdk):
    params = {
        "channelId": 12,
    }
    response = sdk.payments.get_transaction_rule(params)
    print(response)


def create_transaction_rule(sdk):
    payload = {
        "ruleName": "TR2",
        "channelId": "12",
        "feeId": [
            "1",
            "3",
            "5"
        ],
        "dueDays": "7",
        "settlementType": "weekly",
        "settlementDates": "",
        "settlementWeekdays": "Thursday",
        "transactionRuleId": "",
        "status": "",
        "portalId": 2,
        "transactionId": 3
    }
    response = sdk.payments.create_transaction_rule(payload)
    print(response)


def update_transaction_rule(sdk):
    payload = {
        "channelId": "262",
        "feeId": [
            "33"
        ],
        "dueDays": "4",
        "settlementType": "weekly",
        "settlementDates": "2",
        "settlementWeekdays": "Monday,Tuesday",
        "transactionRuleId": "47",
        "status": True,
        "ruleName": "abcd",
        "transactionId": 3
    }
    response = sdk.payments.update_transaction_rule(payload)
    print(response)


def main():
    # Initialize SDK
    sdk = EShopBoxSDK(
        workspace=os.getenv('ESHOPBOX_WORKSPACE', ''),
        client_id=os.getenv('ESHOPBOX_CLIENT_ID', ''),
        client_secret=os.getenv('ESHOPBOX_SECRET_ID', ''),
        refresh_token=os.getenv('ESHOPBOX_REFRESH_TOKEN', '')
    )
    # get_payouts(sdk)
    # get_payout(sdk)
    # create_payout(sdk)
    # update_fee(sdk)
    # create_fee(sdk)
    # get_all_fee(sdk)
    # get_fee(sdk)
    # get_all_transaction_rules(sdk)
    get_transaction_rule(sdk)
    # create_transaction_rule(sdk)
    # update_transaction_rule(sdk)


if __name__ == "__main__":
    main()



class TestWorkflowIntegration:
    pass

    # def test_full_order_flow(self, sdk, requests_mock):
    #     # mock token
    #     requests_mock.post(
    #         "https://auth.myeshopbox.com/api/v1/generateToken",
    #         json={"access_token": "token123"}
    #     )

    #     # 1. Create Order
    #     requests_mock.post(
    #         "https://test.myeshopbox.com/api/v1/orders",
    #         json={"order_id": "O1"}
    #     )

    #     # 2. Create Shipment
    #     requests_mock.post(
    #         "https://test.myeshopbox.com/api/v1/shipments",
    #         json={"shipment_id": "S1"}
    #     )

    #     # 3. Track
    #     requests_mock.get(
    #         "https://test.myeshopbox.com/api/v1/shipments/S1/track",
    #         json={"status": "shipped"}
    #     )

    #     order = sdk.orders.create({"order_number": "123"})
    #     shipment = sdk.shipments.create({"order_id": order["order_id"]})
    #     tracking = sdk.shipments.track(shipment["shipment_id"])

    #     assert tracking["status"] == "shipped"



"""Product model"""

from typing import Optional, List
from pydantic import BaseModel, Field


class Product(BaseModel):
    """Represents a product item"""

    sku: str = Field(..., description="Unique product SKU")
    name: str = Field(..., description="Product name")
    weight: Optional[float] = Field(None, description="Weight in kg")
    height: Optional[float] = Field(None)
    width: Optional[float] = Field(None)
    length: Optional[float] = Field(None)
    price: Optional[float] = Field(None, description="Selling price")
    quantity: Optional[int] = Field(None, description="Available quantity")

    tags: Optional[List[str]] = Field(default=None, description="Product tags list")



"""EShopBox Python SDK - A comprehensive package for EShopBox shipping APIs"""

from eshopbox.__version__ import __version__, __author__, __email__
from eshopbox.client import EShopBoxSDK
from eshopbox.exceptions import (
    EShopBoxException,
    AuthenticationError,
    APIError,
    ValidationError,
    RateLimitError,
    NotFoundError
)

__all__ = [
    'EShopBoxSDK',
    'EShopBoxException',
    'AuthenticationError',
    'APIError',
    'ValidationError',
    'RateLimitError',
    'NotFoundError',
    '__version__'
]


"""Orders API module"""

from typing import Dict, Optional, List
from eshopbox.api.base import BaseAPI


class OrdersAPI(BaseAPI):
    """Handle order-related operations"""
    
    def get_all(self, page: int = 1, **filters) -> Dict:
        """
        Get all orders with optional filters
        
        Args:
            page: Page number for pagination
            **filters: Additional filter parameters
            
        Returns:
            Dict containing order data
        """
        url = f"{self.base_url}/api/v1/orders/erp"
        params = {"filters": f"page={page}"}
        params.update(filters)
        return self._make_request("GET", url, params=params)
    
    def get(self, customer_order_number: str) -> Dict:
        """
        Get a specific order by customer order number
        
        Args:
            customer_order_number: Unique order identifier
            
        Returns:
            Dict containing order details
        """
        url = f"{self.eshopbox_url}/api/order/{customer_order_number}"
        return self._make_request("GET", url)
    
    def create(self, order_data: Dict) -> Dict:
        """
        Create a new order
        
        Args:
            order_data: Order information including items, addresses, etc.
            
        Returns:
            Dict containing created order details
            
        Example:
            >>> order = {
            ...     "externalChannelID": "CH1234",
            ...     "customerOrderNumber": "ORD123",
            ...     "items": [...],
            ...     "shippingAddress": {...}
            ... }
            >>> result = api.orders.create(order)
        """
        url = f"{self.eshopbox_url}/api/order"
        return self._make_request("POST", url, json=order_data)
    
    def cancel(self, cancel_data: Dict) -> Dict:
        """
        Cancel an order
        
        Args:
            cancel_data: Cancellation details including order number and reason
            
        Returns:
            Dict containing cancellation confirmation
        """
        url = f"{self.eshopbox_url}/api/cancel-order"
        return self._make_request("POST", url, json=cancel_data)
    
    def get_invoice(self, order_number: str) -> Dict:
        """
        Get invoice details for an order
        
        Args:
            order_number: Order number
            
        Returns:
            Dict containing invoice details
        """
        url = f"{self.eshopbox_url}/api/invoice-detail/{order_number}"
        return self._make_request("GET", url)



from eshopbox.models.address import Address
from eshopbox.models.product import Product
from eshopbox.models.shipment import Shipment, ShipmentItem
from eshopbox.models.order import Order, OrderItem, PaymentInfo

__all__ = [
    "Address",
    "Product",
    "Shipment",
    "ShipmentItem",
    "Order",
    "OrderItem",
    "PaymentInfo",
]



"""Payments API module"""

from typing import Dict
from eshopbox.api.base import BaseAPI


class PaymentsAPI(BaseAPI):
    """Handle product-related operations"""

    def get_payouts(self) -> Dict:
        """Fetch all products with optional filters."""
        url = f"{self.base_url}/payments/api/v1/payout"
        return self._make_request("GET", url)

    def get_payout(self, params: Dict) -> Dict:
        """Fetch a single product by SKU."""
        url = f"{self.base_url}/payments/api/v1/payout"
        return self._make_request("GET", url, params=params)

    def create_payout(self, payload: Dict) -> Dict:
        """Create a new product."""
        url = f"{self.base_url}/payments/api/v1/payout"
        return self._make_request("POST", url, json=payload)

    def update_fee(self, payload) -> Dict:
        """Create a new product."""
        url = f"{self.base_url}/payments/api/v1/fee"
        return self._make_request("PUT", url, json=payload)

    def create_fee(self, payload: Dict) -> Dict:
        """Create a new product."""
        url = f"{self.base_url}/payments/api/v1/fee"
        return self._make_request("POST", url, json=payload)

    def get_all_fee(self) -> Dict:
        """Create a new product."""
        url = f"{self.base_url}/payments/api/v1/fee"
        return self._make_request("GET", url)

    def get_fee(self, params: Dict) -> Dict:
        """Create a new product."""
        url = f"{self.base_url}/payments/api/v1/fee"
        return self._make_request("GET", url, params=params)

    def get_all_transaction_rules(self) -> Dict:
        """Create a new product."""
        url = f"{self.base_url}/payments/api/v1/transactionRules"
        return self._make_request("GET", url)

    def get_transaction_rule(self, params: Dict) -> Dict:
        """Create a new product."""
        url = f"{self.base_url}/payments/api/v1/transactionRules"
        return self._make_request("GET", url, params=params)

    def create_transaction_rule(self, payload: Dict) -> Dict:
        """Create a new product."""
        url = f"{self.base_url}/payments/api/v1/transactionRules"
        return self._make_request("POST", url, json=payload)

    def update_transaction_rule(self, payload: Dict) -> Dict:
        """Create a new product."""
        url = f"{self.base_url}/payments/api/v1/transactionRules"
        return self._make_request("PUT", url, json=payload)



"""
Example: Setup order using EShopBox SDK
"""

from eshopbox import EShopBoxSDK
import os
from dotenv import load_dotenv
load_dotenv()


def get_all_orders(sdk):
    params = {
        'filters': 'account=kashwork-ecommerce'
    }
    response = sdk.orders.get_all(page=1, **params)
    print("Response: ", response)


def get_order(sdk):
    response = sdk.orders.get('OD119208447831346001')
    print("Response: ", response)


def create_order(sdk):
    order = {
        "externalChannelID": os.getenv('ESHOPBOX_EXTERNAL_CHANNEL_ID'),
        "customerOrderNumber": "OD119208447831346002",
        "orderDate": "2020-02-29 15:39:11",
        "isCOD": "0",
        "paymentType": "DebitCard",
        "shipChargeAmount": 0,
        "subtotal": 4049.09,
        "orderTotal": 4049.09,
        "balanceDue": 0,
        "thirdPartyShipping": False,
        "shippingAddress": {
            "customerName": "Sakib Malik",
            "addressLine1": "D151",
            "addressLine2": "industrail Area",
            "city": "mohali",
            "state": "Punjab",
            "postalCode": "160071",
            "gstin": "27ABCGN5397X1XX",
            "countryCode": "IN",
            "countryName": "India",
            "contactPhone": "xxxxxxxxxx",
            "email": "xxxxxxxxxxxxxxx@gmail.com"
        },
        "billingAddress": {
            "customerName": "Sakib Malik",
            "addressLine1": "D151",
            "addressLine2": "industrail Area",
            "city": "mohali",
            "state": "Punjab",
            "postalCode": "160071",
            "countryCode": "IN",
            "countryName": "India",
            "contactPhone": "xxxxxxxxxx",
            "email": "xxxxxxxxxxxxxxx@gmail.com"
        },
        "items": [
            {
                "lineItemSequenceNumber": 100,
                "itemID": "KW-100",
                "sellerSkuOnChannel": "KW-123",
                "productName": "Keyboard",
                "quantity": 1,
                "customerPrice": 4499,
                "discount": 449.89,
                "lineItemTotal": 4049.09,
                "mrp": 6000,
                "productAdditionalInfo": {
                    "size": "",
                    "color": "",
                    "weight": 20.99,
                    "height": 12.13,
                    "length": 11.13,
                    "width": 8.13,
                    "taxPercentage": 12.00,
                    "hsnCode": "HSN1324"
                },
                "productUrl": "https://kashwork.com/d/jewellery/imitation_jewellery/women_imitation_jewellery_/women_necklace_sets/dabka_jewellery_set/161291130/598744146",
                "productImageUrl": "https://kw-live.s3.amazonaws.com/media/post_images/upload/product_pic_d4bda7fb-e2f1-4061-b2ef-e4a5bd7618b8.webp"
            }
        ]
    }
    response = sdk.orders.create(order)
    print("Response: ", response)


def update_order(sdk):
    pass


def cancel_order(sdk):
    cancel_data = {
        "externalChannelID": os.getenv('ESHOPBOX_EXTERNAL_CHANNEL_ID'),
        "customerOrderNumber": "OD119208447831346002",
        "actor": "xxxxxxxxxxxxxxx@gmail.com",
        "reason": "Cancelled By Customer",
        "cancellationTime": "2018-07-08 22:00:05",
        "items": [
            {
                "lineItemSequenceNumber": 100,
                "itemID": "KW-100",
                "quantity": 1,
                "productName": "Keyboard",
                "remark": "cancelled by customer"
            }
        ]
    }
    response = sdk.orders.cancel(cancel_data)
    print("Response: ", response)


def get_invoice(sdk):
    response = sdk.orders.get_invoice('OD119208447831346002')
    print("Response: ", response)


def main():
    # Initialize SDK
    sdk = EShopBoxSDK(
        workspace=os.getenv('ESHOPBOX_WORKSPACE', ''),
        client_id=os.getenv('ESHOPBOX_CLIENT_ID', ''),
        client_secret=os.getenv('ESHOPBOX_SECRET_ID', ''),
        refresh_token=os.getenv('ESHOPBOX_REFRESH_TOKEN', '')
    )

    # get_all_orders(sdk)
    # get_order(sdk)
    # create_order(sdk)
    # cancel_order(sdk)
    get_invoice(sdk)


if __name__ == "__main__":
    main()



"""Main SDK client for EShopBox"""

from eshopbox.auth import EShopBoxAuth
from eshopbox.api.orders import OrdersAPI
from eshopbox.api.consignments import ConsignmentsAPI
from eshopbox.api.products import ProductsAPI
from eshopbox.api.rate_calculator import RateCalculatorAPI
from eshopbox.api.returns import ReturnsAPI
from eshopbox.api.serviceability import ServiceabilityAPI
from eshopbox.api.shipments import ShipmentsAPI
from eshopbox.api.webhooks import WebhooksAPI
from eshopbox.api.order_status_update import OrderStatusUpdateAPI
from eshopbox.api.wrapper import WrapperAPI
from eshopbox.api.payments import PaymentsAPI
from eshopbox.api.settings import SettingsAPI
# Import other API modules...


class EShopBoxSDK:
    """
    Main SDK class for EShopBox API

    Example:
        >>> sdk = EShopBoxSDK(
        ...     workspace="myshop",
        ...     client_id="client_id",
        ...     client_secret="secret",
        ...     refresh_token="token"
        ... )
        >>> orders = sdk.orders.get_all()
    """

    def __init__(
        self,
        workspace: str,
        client_id: str,
        client_secret: str,
        refresh_token: str
    ):
        """
        Initialize EShopBox SDK

        Args:
            workspace: Your EShopBox workspace name
            client_id: Your API client ID
            client_secret: Your API client secret
            refresh_token: Your API refresh token
        """
        self.workspace = workspace
        self.auth = EShopBoxAuth(client_id, client_secret, refresh_token)

        # Initialize API modules
        self.orders = OrdersAPI(workspace, self.auth)
        self.consignments = ConsignmentsAPI(workspace, self.auth)
        self.products = ProductsAPI(workspace, self.auth)
        self.rate_calculator = RateCalculatorAPI(workspace, self.auth)
        self.returns = ReturnsAPI(workspace, self.auth)
        self.serviceability = ServiceabilityAPI(workspace, self.auth)
        self.shipments = ShipmentsAPI(workspace, self.auth)
        self.order_status_update = OrderStatusUpdateAPI(workspace, self.auth)
        self.webhooks = WebhooksAPI(workspace, self.auth)
        self.wrapper = WrapperAPI(workspace, self.auth)
        self.payments = PaymentsAPI(workspace, self.auth)
        self.settings = SettingsAPI(workspace, self.auth)



import pytest
from eshopbox.exceptions import APIError


class TestAuthAPI:
    pass
    # def test_generate_token_success(self, sdk, requests_mock):
    #     requests_mock.post(
    #         "https://auth.myeshopbox.com/api/v1/generateToken",
    #         json={"access_token": "xyz123"}
    #     )
    #     token = sdk.auth.generate_token()
    #     assert token == "xyz123"

    # def test_generate_token_failure(self, sdk, requests_mock):
    #     requests_mock.post(
    #         "https://auth.myeshopbox.com/api/v1/generateToken",
    #         status_code=400,
    #         json={"error": "invalid_auth"}
    #     )

    #     with pytest.raises(APIError):
    #         sdk.auth.generate_token()



"""Shipment model"""

from typing import Optional, List
from pydantic import BaseModel, Field
from eshopbox.models.address import Address


class ShipmentItem(BaseModel):
    """Represents an item inside a shipment."""

    sku: str = Field(..., description="Product SKU")
    quantity: int = Field(..., ge=1, description="Quantity shipped")


class Shipment(BaseModel):
    """Represents a shipment."""

    shipment_id: str = Field(..., description="Unique shipment ID")
    awb_number: Optional[str] = Field(None, description="Airway bill number")
    courier: Optional[str] = Field(None, description="Courier partner name")

    sender: Address
    recipient: Address

    items: List[ShipmentItem] = Field(..., description="List of items in shipment")
    status: Optional[str] = Field(None, description="Shipment current status")



import pytest


class TestProductsAPI:
    pass

    # def test_get_products(self, sdk, mock_token, requests_mock):
    #     requests_mock.get(
    #         "https://test.myeshopbox.com/api/v1/products",
    #         json={"products": []}
    #     )

    #     result = sdk.products.get_all()
    #     assert "products" in result

    # def test_get_single_product(self, sdk, mock_token, requests_mock):
    #     requests_mock.get(
    #         "https://test.myeshopbox.com/api/v1/products/SKU123",
    #         json={"sku": "SKU123"}
    #     )

    #     product = sdk.products.get("SKU123")
    #     assert product["sku"] == "SKU123"



"""
Example: Track shipment using EShopBox SDK
"""

from eshopbox import EShopBoxSDK
import os
from dotenv import load_dotenv
load_dotenv()


def get_all_shipments(sdk):
    shipments = sdk.shipments.get_all()
    print(shipments)


def get_shipment(sdk):
    shipment = sdk.shipments.get("OD119208447831346000-4380-3659")
    print(shipment)


def create_shipment(sdk):
    payload = {
        "customerOrderNumber": "OD119208447831346000",
        "vendorOrderNumber": "OD119208447831346000",
        "externalShipmentID": "300884672-5-87",
        "externalWarehouseID": "W4585",
        "externalChannelID": "{{externalChannelID}}",
        "defaultWarehouseCode": "2022",
        "orderDate": "2020-03-18 15:52:38",
        "portal_id": 12,
        "paymentType": "COD",
        "expectedShipDate": None,
        "externalManifestNumber": None,
        "channelManifestNumber": None,
        "order_id": 1576882,
        "channel_id": 271,
        "warehouse_id": 21,
        "channel_account_id": None,
        "account_id": 6,
        "region": "Local",
        "picklistCode": None,
        "invoiceNumber": "SESI1687",
        "boxType": "UNKNOWN",
        "isPriorityShipment": "0",
        "isGift": "0",
        "invoice_url": "",
        "invoiceDate": "2020-03-19 00:00:00",
        "label_url": "https://pyck-res-bucket.s3.amazonaws.com:443/DELHIVERY/2020-03-18/2098310486496.pdf",
        "labels": "",
        "shippingInfo": [],
        "boxAdditionalRecommendation": [],
        "dimension_length": "10",
        "dimension_width": "20",
        "dimension_height": "12",
        "weight": "1231",
        "trackingID": "2098310486496",
        "packageID": "",
        "barcode": "",
        "courierName": "Delhivery",
        "created_at": "2020-03-18 21:22:57",
        "updated_at": "2020-03-19 01:54:20",
        "status": "intransit",
        "remarks": "shipment picked up from client location",
        "customerName": "Sakib Malik",
        "customerContactNumber": "xxxxxxxxxx",
        "email": "xxxxxxxxxxxxxxx@gmail.com",
        "channelSlug": "blackberrys",
        "status_updated_at": "2020-03-19 14:50:29",
        "status_log": {
            "intransit": "2020-03-19 14:50:29",
            "dispatched": "2020-03-19 06:30:34",
            "packed": "2020-03-19 01:54:23",
            "created": "2020-03-18 21:22:57"
        },
        "orderExternalCreatedAt": "2020-03-18 21:22:52",
        "shippingAddress": {
            "customerName": "Sakib Malik",
            "addressLine1": "D151",
            "addressLine2": "industrail Area",
            "city": "Mohali",
            "state": "Punjab",
            "postalCode": "160071",
            "countryCode": "IN",
            "countryName": "India",
            "contactPhone": "xxxxxxxxxx",
            "email": "xxxxxxxxxxxxxxx@gmail.com"
        },
        "id": 1583574,
        "isCOD": "1",
        "track_payload": {
            "clickPostTrackData": {
                "status": "In Transit",
                "clickpost_status_description": "InTransit",
                "waybill": "2098310486496",
                "account_code": "Delhivery Surface",
                "location": "Gurgaon_Bilaspur_P (Haryana)",
                "clickpost_status_code": 5,
                "remark": "Shipment Picked Up from Client Location",
                "cp_id": 4,
                "timestamp": "2020-03-19T13:48:28Z",
                "additional": {
                    "latest_status": {
                        "clickpost_status_bucket_description": "In transit",
                        "clickpost_status_description": "InTransit",
                        "reference_number": "BLCK103443-271-49",
                        "clickpost_status_bucket": 3,
                        "status": "In Transit",
                        "location": "Gurgaon_Bilaspur_P (Haryana)",
                        "clickpost_status_code": 5,
                        "remark": "Shipment Picked Up from Client Location",
                        "timestamp": "2020-03-19T13:48:28Z"
                    },
                    "destination_hub_inscan_ts": None,
                    "courier_partner_edd": None,
                    "is_rvp": None
                }
            }
        },
        "packed_date": "2020-03-19 01:54:23",
        "items": [
            {
                "id": 49252802,
                "lineItemSequenceNumber": 112988,
                "orderItemID": "OD119208447831346000-49252802",
                "itemID": "DB9U03FMGWZ",
                "sku": "2316W3I7KID",
                "productName": "Pace Barnes",
                "quantity": 1,
                "customerPrice": 4499,
                "discount": 449.89,
                "lineItemTotal": 4049.09,
                "taxRate": 12,
                "taxAmount": 0,
                "giftMessage": "",
                "giftLabelContent": "",
                "cancellationReason": "",
                "cancellationTime": "0000-00-00 00:00:00",
                "original_order_item_id": None,
                "isVirtualKit": "0",
                "productAdditionalInfo": {
                    "size": None,
                    "color": None,
                    "weight": 20.99,
                    "height": 12.13,
                    "length": 11.13,
                    "width": 8.13,
                    "taxPercentage": 12,
                    "hsnCode": "HSN1324",
                    "productDetails": {
                        "hsnCode": "HSN1324",
                        "dimensionHeight": 12.13,
                        "dimensionLength": 11.13,
                        "description": "Pace Barnes",
                        "weight": 20.99,
                        "mrp": 6000,
                        "dimensionWidth": 8.13,
                        "type": "BASE",
                        "taxCode": "ESBGST9",
                        "imageUrl": "https://s3-eu-west-1.amazonaws.com/imagebucketeshopbox/Uzip/219045371-1-40/1.JPG",
                        "accountSlug": "kashwork-ecommerce",
                        "sku": "ABD-123",
                        "esin": "2316W3I7KID",
                        "status": "DRAFT",
                        "weightUnit": "g"
                    }
                },
                "productImageUrl": "https://s3-eu-west-1.amazonaws.com/imagebucketeshopbox/Uzip/219045371-1-40/1.JPG",
                "productUrl": "https://montecarlo.auperator.co/product/edit-product/BBAPLMC144105_44",
                "invoiceTotal": 4049.09,
                "shippingCharges": 0,
                "giftWrapCharges": 0,
                "cashOnDeliveryCharges": 0
            }
        ],
    }
    shipment = sdk.shipments.create(payload)
    print(shipment)


def update(sdk):
    shipment = sdk.shipments.update("OD119208447831346000-4380-3659", "dispatched")
    print(shipment)


def main():
    sdk = EShopBoxSDK(
        workspace=os.getenv('ESHOPBOX_WORKSPACE', ''),
        client_id=os.getenv('ESHOPBOX_CLIENT_ID', ''),
        client_secret=os.getenv('ESHOPBOX_SECRET_ID', ''),
        refresh_token=os.getenv('ESHOPBOX_REFRESH_TOKEN', '')
    )
    # get_all_shipments(sdk)
    # get_shipment(sdk)
    # create_shipment(sdk)
    update(sdk)


if __name__ == "__main__":
    main()



"""Wrapper API module"""

from typing import Dict, Optional, List
from eshopbox.api.base import BaseAPI


class WrapperAPI(BaseAPI):
    """Handle order-related operations"""

    def order(self, payload: Dict) -> Dict:
        """
        Get all orders with optional filters

        Args:
            payload: Dictionary containing filter parameters and pagination info

        Returns:
            Dict containing order data
        """
        url = f"{self.eshopbox_url}/api/v1/shipping/order"
        return self._make_request("POST", url, json=payload)

    def shipping_return(self, payload: Dict) -> Dict:
        """
        Process a shipping return

        Args:
            payload: Return details including order number and return information

        Returns:
            Dict containing return confirmation
        """
        url = f"{self.eshopbox_url}/api/v1/shipping/return"
        return self._make_request("POST", url, json=payload)

    def cancel_tracking(self, payload: Dict) -> Dict:
        """
        Cancel tracking for a shipment

        Args:
            payload: Dictionary containing tracking cancellation details (e.g., order number, reason)

        Returns:
            Dict containing cancellation confirmation
        """
        url = f"{self.eshopbox_url}/api/v1/shipping/cancel"
        return self._make_request("POST", url, json=payload)

    def tracking_details(self, params: Dict) -> Dict:
        """
        Get tracking details for a shipment

        Args:
            params: Dictionary containing tracking query parameters (e.g., order number, shipment ID)

        Returns:
            Dict containing tracking information
        """
        url = f"{self.eshopbox_url}/api/v1/shipping/trackingDetails"
        return self._make_request("GET", url, params=params)

    def webhook_register(self, body: Dict, ProxyHost: str) -> Dict:
        """
        Registering webhook for tracking shipment

        Args:
            params: Dictionary containing tracking query parameters (e.g., order number, shipment ID)

        Returns:
            Dict containing tracking information
        """
        headers = {
            "ProxyHost": ProxyHost
        }
        url = f"{self.base_url}/api/v1/webhook"
        return self._make_request("POST", url, json=body, headers=headers)



"""Consignments API module"""

from typing import Dict
from eshopbox.api.base import BaseAPI


class ConsignmentsAPI(BaseAPI):
    """Handle consignments operations"""

    def get_all(self, page: int = 1) -> Dict:
        """Fetch all consignments."""
        url = f"{self.base_url}/api/v1/consignments"
        params = {"page": page}
        return self._make_request("GET", url, params=params)

    def get(self, consignment_id: str) -> Dict:
        """Fetch consignment details by ID."""
        url = f"{self.eshopbox_url}/api/consignment/{consignment_id}"
        return self._make_request("GET", url)

    def create(self, consignment_data: Dict) -> Dict:
        """Create a new consignment."""
        url = f"{self.eshopbox_url}/api/consignment"
        return self._make_request("POST", url, json=consignment_data)



"""
Example: Setup Products using EShopBox SDK
"""

from eshopbox import EShopBoxSDK
import os
from dotenv import load_dotenv
load_dotenv()


def get_all(sdk):
    params = {
        "fields": "12",
        "ids": "12"
    }
    response = sdk.products.get_all(params)
    print(response)


def get(sdk):
    response = sdk.products.get("kw-12")
    print(response)


def create(sdk):
    product_data = {
        "type": "BASE",
        "sku": "73682939-172882-32",
        "groupCode": "73682939-172882",
        "vertical": "APL",
        "brand": "Kapas Kraft",
        "description": "Rust Regular Fit Bundi",
        "specification": [
            "Fragile",
            "Dangerous",
            "Liquid"
        ],
        "additionalNames": {
            "ean": "89027189271829",
            "upc": "87162143127",
            "gtin": "8276174829301",
            "others": [
                "57182_Brown_32"
            ]
        }
    }
    response = sdk.products.create(product_data)
    print(response)


def update(sdk):
    product_data = {
        "imageUrl": "https://cdn.filestackcontent.com/hdYluVCqSADCASjjjcuaeC.png",
        "mrp": 1499.0,
        "unitPrice": 799.0,
        "hsnCode": "6101112",
        "weight": 167.0,
        "dimensionLength": 5.0,
        "dimensionWidth": 5.0,
        "dimensionHeight": 5.0,
        "dimensionUnit": "cm"
    }
    response = sdk.products.update("73682939-172882-32", product_data)
    print(response)


def delete(sdk):
    response = sdk.products.delete("73682939-172882-32")
    print(response)


def merge_product(sdk):
    payload = {
        "fromProductESIN": "dgdfgfd",
        "toProductESIN": "sdkdgl"
    }
    response = sdk.products.merge_product(payload)
    print(response)


def product_availability(sdk):
    payload = {
        "esin": "0SGAT12SG25F",
        "channelCode": "CH1234",
        "availability": False
    }
    response = sdk.products.product_availability(payload)
    print(response)


def get_all_brands(sdk):
    response = sdk.products.get_all_brands()
    print(response)


def get_brand(sdk):
    response = sdk.products.get_brand("1429")
    print(response)


def create_brand(sdk):
    payload = {
        "brandName": "SAKIB",
        "verticals": [
            {
                "verticalId": "1",
                "verticalName": "apparels",
                "verticalCode": "apl",
                "mainImage": "abc.jpg",
                "hoverImage": "abc.jpg"
            },
            {
                "verticalId": "2",
                "verticalName": "footwear",
                "verticalCode": "ftq",
                "mainImage": "abc.jpg",
                "hoverImage": "abc.jpg"
            }
        ],
        "accountId": "123",
        "brandCode": "ABC123",
        "brandStatus": "1",
        "webSiteLink": "http://Kapas Kraft",
        "brandLogoImage": "Kpas Kraft logo.jpg",
        "tmRegistrationStatus": "abc",
        "tmCertificateScannedCopy": "URL",
        "tAckNo": "1",
        "tmRegistrationNo": "123",
        "tmRegistrationDate": "2019-03-20 00:00:00",
        "tmAckCert": "URL"
    }
    response = sdk.products.create_brand(payload)
    print(response)


def update_brand(sdk):
    payload = {
        "brandName": "SAKIB",
        "verticals": [
            {
                "verticalId": "1",
                "verticalName": "apparels",
                "verticalCode": "apl",
                "mainImage": "abc.jpg",
                "hoverImage": "abc.jpg"
            },
            {
                "verticalId": "2",
                "verticalName": "footwear",
                "verticalCode": "ftq",
                "mainImage": "abc.jpg",
                "hoverImage": "abc.jpg"
            }
        ],
        "accountId": "XXX",
        "brandCode": "ABC123",
        "brandStatus": "1",
        "webSiteLink": "XXXXXXXXXXXX Kraft",
        "brandLogoImage": "Kpas Kraft logo.jpg",
        "tmRegistrationStatus": "abc",
        "tmCertificateScannedCopy": "URL",
        "tAckNo": "1",
        "tmRegistrationNo": "123",
        "tmRegistrationDate": "2019-03-20 00:00:00",
        "tmAckCert": "URL"
    }
    response = sdk.products.update_brand('6312', payload)
    print(response)


def get_inventory_for_given_product_v1(sdk):
    payload = {
        "skus": [
            "kw-100"
        ]
    }
    response = sdk.products.get_inventory_for_given_product_v1(payload)
    print(response)


def get_inventory_for_given_product_v2(sdk):
    params = {
        "page": 1
    }
    response = sdk.products.get_inventory_for_given_product_v2(params)
    print(response)


def get_inventory_summary(sdk):
    params = {
        "warehouseId": 1
    }
    response = sdk.products.get_inventory_summary(params)
    print(response)


def main():
    # Initialize SDK
    sdk = EShopBoxSDK(
        workspace=os.getenv('ESHOPBOX_WORKSPACE', ''),
        client_id=os.getenv('ESHOPBOX_CLIENT_ID', ''),
        client_secret=os.getenv('ESHOPBOX_SECRET_ID', ''),
        refresh_token=os.getenv('ESHOPBOX_REFRESH_TOKEN', '')
    )
    # get_all(sdk)
    # get(sdk)
    # create(sdk)
    # update(sdk)
    # delete(sdk)
    # merge_product(sdk)
    # product_availability(sdk)
    # get_all_brands(sdk)
    # get_brand(sdk)
    # create_brand(sdk)
    # update_brand(sdk)
    # get_inventory_for_given_product_v1(sdk)
    # get_inventory_for_given_product_v2(sdk)
    get_inventory_summary(sdk)


if __name__ == "__main__":
    main()



"""Returns API module"""

from typing import Dict
from eshopbox.api.base import BaseAPI


class ReturnsAPI(BaseAPI):
    """Handle returns operations"""

    def get_all(self, page: int = 1) -> Dict:
        """Fetch all returns."""
        url = f"{self.base_url}/api/v1/returns"
        params = {"page": page}
        return self._make_request("GET", url, params=params)

    def get(self, return_id: str) -> Dict:
        """Fetch return details."""
        url = f"{self.eshopbox_url}/api/return/{return_id}"
        return self._make_request("GET", url)

    def create(self, return_data: Dict) -> Dict:
        """Create a return request."""
        url = f"{self.eshopbox_url}/api/return"
        return self._make_request("POST", url, json=return_data)



"""
Example: Setup webhook using EShopBox SDK
"""

import os
from eshopbox.client import EShopBoxSDK
from dotenv import load_dotenv
load_dotenv()


def get_all_webhooks(sdk):
    print("Getting all webhooks...")
    response = sdk.webhooks.list()
    print("Webhooks retrieved successfully!")
    print(response)


def get_webhooks(sdk, id):
    print("Getting specific webhooks...")
    response = sdk.webhooks.get(id)
    print("Webhooks retrieved successfully!")
    print(response)


def create_webhooks(sdk):
    print("Creating webhook...")
    webhook_data = {
        "resource": "user_invitation",
        "eventType": "POST",
        "eventSubType": "created",
        "version": "v1",
        "externalChannelID": os.getenv('ESHOPBOX_EXTERNAL_CHANNEL_ID', ''),
        "webhookUrl": "https://api-dev.kashwork.com/api/shipping/eshopbox/webhook",
        "webhookMethod": "POST",
        "accountSlug": os.getenv('ESHOPBOX_WORKSPACE', '')
    }
    response = sdk.webhooks.create(webhook_data)
    print("Webhook created successfully!")
    print(response)


def update_webhooks(sdk, id):
    print("Updating webhook...")
    webhook_data = {
        "id": id,
        "resource": "channel_inventory",
        "eventType": "POST",
        "eventSubType": "created",
        "version": "v1",
        "externalChannelID": os.getenv('ESHOPBOX_EXTERNAL_CHANNEL_ID', ''),
        "webhookUrl": "https://api-dev.kashwork.com/api/shipping/eshopbox/webhook",
        "webhookMethod": "POST",
        "accountSlug": os.getenv('ESHOPBOX_WORKSPACE', '')
    }
    response = sdk.webhooks.update(webhook_data)
    print("Webhook updated successfully!")
    print(response)


def main():
    sdk = EShopBoxSDK(
        workspace=os.getenv('ESHOPBOX_WORKSPACE', ''),
        client_id=os.getenv('ESHOPBOX_CLIENT_ID', ''),
        client_secret=os.getenv('ESHOPBOX_SECRET_ID', ''),
        refresh_token=os.getenv('ESHOPBOX_REFRESH_TOKEN', '')
    )

    # get_all_webhooks(sdk)
    # get_webhooks(sdk, '105322')
    # create_webhooks(sdk)
    update_webhooks(sdk, '105322')


if __name__ == "__main__":
    main()



"""
Example: Manage Inventory using EShopBox SDK
"""

from eshopbox import EShopBoxSDK
import os
from dotenv import load_dotenv
load_dotenv()


def main():
    sdk = EShopBoxSDK(
        workspace=os.getenv('ESHOPBOX_WORKSPACE', ''),
        client_id=os.getenv('ESHOPBOX_CLIENT_ID', ''),
        client_secret=os.getenv('ESHOPBOX_SECRET_ID', ''),
        refresh_token=os.getenv('ESHOPBOX_REFRESH_TOKEN', '')
    )

    sku = "SKU1234"

    print(f"Fetching inventory for {sku}...")
    inventory = sdk.inventory.get_stock(sku)
    print("Current stock:", inventory)

    print(f"Updating inventory for {sku}...")
    update_payload = {
        "sku": sku,
        "quantity": 25
    }

    updated = sdk.inventory.update_stock(update_payload)
    print("Updated stock:", updated)


if __name__ == "__main__":
    main()



"""Shipments API module"""

from typing import Dict
from eshopbox.api.base import BaseAPI


class ShipmentsAPI(BaseAPI):
    """Handle shipment-related operations"""

    def get_all(self, page: int = 1) -> Dict:
        """Get all shipments."""
        url = f"{self.eshopbox_url}/api/order/shipment"
        params = {"page": page}
        return self._make_request("GET", url, params=params)

    def get(self, externalShipmentId: str) -> Dict:
        """Get a shipment."""
        url = f"{self.eshopbox_url}/api/order/shipment/{externalShipmentId}"
        return self._make_request("GET", url)

    def create(self, payload: Dict) -> Dict:
        """Create a shipment."""
        url = f"{self.eshopbox_url}/api/order/shipment"
        return self._make_request("POST", url, json=payload)

    def update(self, externalShipmentID: str, status: str) -> Dict:
        """Create a shipment."""
        url = f"{self.eshopbox_url}/api/order/shipment/{externalShipmentID}/mark{status}"
        return self._make_request("PUT", url)



"""Rate Calculator API module"""

from typing import Dict
from eshopbox.api.base import BaseAPI


class RateCalculatorAPI(BaseAPI):
    """Calculate shipping rates"""

    def calculate(self, rate_data: Dict) -> Dict:
        """Calculate shipping rate."""
        url = f"{self.base_url}/shipping/api/v1/calculate/rate"
        return self._make_request("POST", url, json=rate_data)



"""Address model"""

from typing import Optional
from pydantic import BaseModel, Field, validator


class Address(BaseModel):
    """Represents a customer or warehouse address."""

    name: str = Field(..., description="Full name of the recipient")
    line1: str = Field(..., description="Address line 1")
    line2: Optional[str] = Field(None, description="Address line 2")
    city: str = Field(..., description="City name")
    state: str = Field(..., description="State name")
    pincode: str = Field(..., min_length=6, max_length=6, description="6-digit postal code")
    phone: str = Field(..., min_length=10, max_length=15, description="Contact number")
    email: Optional[str] = Field(None, description="Email address")

    @validator("pincode")
    def validate_pincode(cls, v):
        if not v.isdigit():
            raise ValueError("Pincode must contain only digits")
        return v



"""
Example: Setup Serviceability using EShopBox SDK
"""

import os
from eshopbox.client import EShopBoxSDK
from dotenv import load_dotenv
load_dotenv()


def get_serviceability_pin_code_based(sdk):
    payload = {
        "dropPincode": "160071",
        "pickupPincode": "247342",
        "deadWeight": 500,
        "length": 12,
        "height": 10,
        "width": 8,
        "isCod": False
    }
    response = sdk.serviceability.pincodeserviceability(payload)
    print("Response: ", response)


def get_productserviceability(sdk):
    payload = {
        "dropPincode": "160071",
        "productId": "sakib"
    }
    response = sdk.serviceability.productserviceability(payload)
    print("Response: ", response)


def get_checkpincodeserviceability(sdk):
    payload = {
        "deliveryPincode": "160071",
        "pickupPincode": "247342"
    }
    response = sdk.serviceability.checkpincodeserviceability(payload)
    print("Response: ", response)


def get_get_bulk_pin_code_serviceability(sdk):
    params = {
        "shippingMode": "standard"
    }
    response = sdk.serviceability.bulkPincodeServiceability(params)
    print("Response: ", response)


def main():
    sdk = EShopBoxSDK(
        workspace=os.getenv('ESHOPBOX_WORKSPACE', ''),
        client_id=os.getenv('ESHOPBOX_CLIENT_ID', ''),
        client_secret=os.getenv('ESHOPBOX_SECRET_ID', ''),
        refresh_token=os.getenv('ESHOPBOX_REFRESH_TOKEN', '')
    )
    # get_serviceability_pin_code_based(sdk)
    # get_productserviceability(sdk)
    # get_checkpincodeserviceability(sdk)
    get_get_bulk_pin_code_serviceability(sdk)


if __name__ == "__main__":
    main()



"""Custom exceptions for EShopBox SDK"""


class EShopBoxException(Exception):
    """Base exception for EShopBox SDK"""
    pass


class AuthenticationError(EShopBoxException):
    """Raised when authentication fails"""
    pass


class APIError(EShopBoxException):
    """Raised when API returns an error"""
    
    def __init__(self, message, status_code=None, response=None):
        super().__init__(message)
        self.status_code = status_code
        self.response = response


class ValidationError(EShopBoxException):
    """Raised when input validation fails"""
    pass


class RateLimitError(EShopBoxException):
    """Raised when rate limit is exceeded"""
    pass


class NotFoundError(EShopBoxException):
    """Raised when resource is not found"""
    pass


"""
Example: Setup Wrapper using EShopBox SDK
"""

from eshopbox import EShopBoxSDK
import os
from dotenv import load_dotenv
load_dotenv()


def order(sdk):
    payload = {
        "channelId": os.getenv('ESHOPBOX_EXTERNAL_CHANNEL_ID'),
        "customerOrderId": "OD119208447831346001",
        "shipmentId": "OD119208447831346001-4380-3659",
        "orderDate": "2024-01-01 09:00:00",
        "isCOD": True,
        "invoiceTotal": 4049.09,
        "shippingMode": "Eshopbox Standard",
        "invoice": {
            "number": "C00011323A000002",
            "date": "2024-01-04 09:00:00"
        },
        "ewaybillNumber": "123422267332",
        "balanceDue": 0,
        "shippingAddress": {
            "customerName": "Sakib Malik",
            "addressLine1": "D151",
            "addressLine2": "industrail Area",
            "city": "Mohali",
            "state": "Punjab",
            "postalCode": "160071",
            "countryCode": "IN",
            "country": "India",
            "contactPhone": "xxxxxxxxxx",
            "email": "xxxxxxxxxxxxxxx@gmail.com",
            "gstin": "344633257673"
        },
        "billingIsShipping": True,
        "billingAddress": {
            "customerName": "Sakib Malik",
            "addressLine1": "D151",
            "addressLine2": "industrail Area",
            "city": "Mohali",
            "state": "Punjab",
            "postalCode": "160071",
            "countryCode": "IN",
            "countryName": "India",
            "contactPhone": "xxxxxxxxxx",
            "email": "xxxxxxxxxxxxxxx@gmail.com"
        },
        "items": [
            {
                "id": 49252941,
                "lineItemSequenceNumber": 100,
                "orderItemID": "OD119208447831346001-49252941",
                "itemID": "KW-100",
                "sku": "23YCU3I7KIF",
                "productName": "Keyboard",
                "quantity": 1,
                "customerPrice": 4499,
                "discount": 449.89,
                "lineItemTotal": 4049.09,
                "taxRate": 12,
                "taxAmount": 0,
                "giftMessage": "",
                "giftLabelContent": "",
                "cancellationReason": "",
                "cancellationTime": "0000-00-00 00:00:00",
                "original_order_item_id": None,
                "isVirtualKit": "0",
                "productAdditionalInfo": {
                    "size": None,
                    "color": None,
                    "weight": 20.99,
                    "height": 12.13,
                    "length": 11.13,
                    "width": 8.13,
                    "taxPercentage": 12,
                    "hsnCode": "HSN1324",
                    "productDetails": {
                        "hsnCode": "HSN1324",
                        "dimensionHeight": 12.13,
                        "dimensionLength": 11.13,
                        "description": "Keyboard",
                        "weight": 20.99,
                        "mrp": 6000,
                        "dimensionWidth": 8.13,
                        "type": "BASE",
                        "taxCode": "ESBGST9",
                        "imageUrl": "https://kw-live.s3.amazonaws.com/media/post_images/upload/product_pic_d4bda7fb-e2f1-4061-b2ef-e4a5bd7618b8.webp",
                        "accountSlug": "kashwork-ecommerce",
                        "sku": "KW-123",
                        "esin": "23YCU3I7KIF",
                        "status": "DRAFT",
                        "weightUnit": "g"
                    }
                },
                "productImageUrl": "https://kw-live.s3.amazonaws.com/media/post_images/upload/product_pic_d4bda7fb-e2f1-4061-b2ef-e4a5bd7618b8.webp",
                "productUrl": "https://kashwork.com/d/jewellery/imitation_jewellery/women_imitation_jewellery_/women_necklace_sets/dabka_jewellery_set/161291130/598744146",
                "invoiceTotal": 4049.09,
                "shippingCharges": 0,
                "giftWrapCharges": 0,
                "cashOnDeliveryCharges": 0
            }
        ],
        "shipmentDimension": {
            "length": 13.12,
            "breadth": 15.32,
            "height": 56.39,
            "weight": 201.23
        },
        "pickupLocation": {
            "locationCode": "MCFL00395",
            "locationName": "TEST Warehouse",
            "companyName": "TEST",
            "contactPerson": "SAM",
            "contactNumber": "898898989",
            "addressLine1": "Khasra no 5/16/2,17, Near Subash Chowk, Sohana Road Village Behrampur",
            "addressLine2": "Khasra no 5/16/2,17, Near Subash Chowk",
            "city": "Gurgaon",
            "state": "HARYANA",
            "country": "India",
            "pincode": "121005",
            "gstin": "06AAFCM7888Q1ZE"
        },
        "package": {
            "type": "box",
            "code": "PC20240613141533",
            "description": "Test1",
            "length": 45.00,
            "breadth": 54.13,
            "height": 45.22,
            "weight": 45.80
        }
    }
    response = sdk.wrapper.order(payload)
    print("Response: ", response)


def shipping_return(sdk):
    payload = {
        "channelId": "KAPAS KRAFT",
        "customerOrderId": "OD119208447831346000",
        "shipmentId": "2313ewqwre",
        "orderDate": "2020-02-29 15:39:11",
        "isCOD": True,
        "invoiceTotal": 4049.09,
        "shippingMode": "Standard",
        "invoice": {
            "number": "C00011323A000002",
            "date": "2023-06-02 15:39:11"
        },
        "ewaybillNumber": "",
        "shippingAddress": {
            "locationCode": "MCFL00395",
            "locationName": "TEST Warehouse",
            "companyName": "TEST",
            "contactPerson": "SAM",
            "contactNumber": "898898989",
            "addressLine1": "Khasra no 5/16/2,17, Near Subash Chowk, Sohana Road Village Behrampur",
            "addressLine2": "Khasra no 5/16/2,17, Near Subash Chowk",
            "city": "Gurgaon",
            "pincode": "121005",
            "state": "HARYANA",
            "country": "India",
            "gstin": "06AAFCM7888Q1ZE"
        },
        "items": [
            {
                "itemID": "DB9U03FMGWZ",
                "productTitle": "Pace Barnes",
                "quantity": 1,
                "itemTotal": 4049.09,
                "hsn": "122132",
                "mrp": 2345.98,
                "discount": 123,
                "taxPercentage": 12.00,
                "returnReason": "TEST",
                "ean": "2342534",
                "length": 12,
                "breadth": 18,
                "height": 23,
                "weight": 100,
                "qcDetails": {
                    "qc_color": "red",
                    "qc_brand": "duke",
                    "qc_serial_no": "212324235",
                    "qc_ean_barcode": "sdsrewrt",
                    "qc_size": "22",
                    "qc_product_name": "TEST",
                    "qc_product_image": "IMG.png",
                    "qcParamsToCheck": [
                        "check_price_tag",
                        "check_packaging_box",
                        "check_damaged",
                        "check_used"
                    ]
                }
            }
        ],
        "returnDimension": {
            "length": 13.12,
            "breadth": 15.32,
            "height": 56.39,
            "weight": 201.23
        },
        "pickupLocation": {
            "customerName": "John Doe",
            "addressLine1": "Kapas Kraft Apparels Limited",
            "addressLine2": "Banglore",
            "city": "bengluru",
            "state": "Karnataka",
            "pincode": "560005",
            "country": "India",
            "contactPhone": "9998889998",
            "email": "johndoe@gmail.com"
        }
    }
    response = sdk.wrapper.shipping_return(payload)
    print("Response: ", response)


def cancel_tracking(sdk):
    payload = {
        "trackingId": "1231244"
    }
    response = sdk.wrapper.cancel_tracking(payload)
    print("Response: ", response)


def tracking_details(sdk):
    params = {
        "trackingIds": "OD119208447831346000-4380-3659",
    }
    response = sdk.wrapper.tracking_details(params)
    print("Response: ", response)


def webhook_register(sdk):
    payload = {
        "resource": "channel_inventory",
        "eventType": "POST",
        "eventSubType": "updated",
        "version": "v1",
        "externalChannelID": "TEST",
        "webhookUrl": "https://webhook.testurl.com/fake-subscription-url2",
        "webhookMethod": "POST",
        "webhookHeaders": {
            "x-api-key": "test1234",
            "sample-header-key": "test875876",
            "authorization": "Bearer abcdef123456",
            "custom-header": "customValue",
            "content-type": "application/json"
        }
    }

    response = sdk.wrapper.webhook_register(payload, ProxyHost="your_proxy_host_value")
    print("Response: ", response)


def main():
    # Initialize SDK
    sdk = EShopBoxSDK(
        workspace=os.getenv('ESHOPBOX_WORKSPACE', ''),
        client_id=os.getenv('ESHOPBOX_CLIENT_ID', ''),
        client_secret=os.getenv('ESHOPBOX_SECRET_ID', ''),
        refresh_token=os.getenv('ESHOPBOX_REFRESH_TOKEN', '')
    )
    # order(sdk)
    # shipping_return(sdk)
    # cancel_tracking(sdk)
    # tracking_details(sdk)
    webhook_register(sdk)


if __name__ == "__main__":
    main()



"""OrderStatusUpdate API module"""

from typing import Dict
from eshopbox.api.base import BaseAPI


class OrderStatusUpdateAPI(BaseAPI):
    """Handle shipment-related operations"""

    def create_label_and_awb(self, payload: Dict) -> Dict:
        """Create Label And Awb."""
        url = f"{self.eshopbox_url}/api/unicommerce/orders/labels"
        return self._make_request("POST", url, json=payload)

    def get_awb_and_courier_name(self, params: Dict) -> Dict:
        """Get Awb And Courier Name."""
        url = f"{self.eshopbox_url}/api/unicommerce/courierDetails"
        return self._make_request("GET", url, params=params)

    def dispatch_shipment(self, payload: Dict) -> Dict:
        """Dispatch Shipment."""
        url = f"{self.eshopbox_url}/api/unicommerce/orders/dispatch"
        return self._make_request("POST", url, json=payload)

    def courier_details_for_return(self, externalShipmentID: str) -> Dict:
        """Courier Details For Return."""
        url = f"{self.eshopbox_url}/api/get-return-courier/{externalShipmentID}"
        return self._make_request("GET", url)

    def update(self, payload: Dict) -> Dict:
        """Update Order Status."""
        url = f"{self.eshopbox_url}/api/update-status"
        return self._make_request("POST", url, json=payload)




import pytest
from eshopbox import EShopBoxSDK
from eshopbox.exceptions import APIError, ValidationError


class TestOrdersAPI:

    @pytest.fixture
    def sdk(self):
        return EShopBoxSDK(
            workspace="test",
            client_id="test_id",
            client_secret="test_secret",
            refresh_token="test_token"
        )

    def test_get_all_orders(self, sdk, requests_mock):
        requests_mock.post(
            "https://auth.myeshopbox.com/api/v1/generateToken",
            json={"access_token": "test_token"}
        )
        requests_mock.get(
            "https://test.myeshopbox.com/api/v1/orders/erp",
            json={"orders": []}
        )

        result = sdk.orders.get_all()
        assert "orders" in result

    def test_create_order(self, sdk, requests_mock):
        # Test implementation...
        pass



"""Authentication handler for EShopBox API"""

import requests
from typing import Dict, Optional
from datetime import datetime, timedelta
from eshopbox.exceptions import AuthenticationError


class EShopBoxAuth:
    """Handle authentication for EShopBox API"""
    
    AUTH_URL = "https://auth.myeshopbox.com/api/v1/generateToken"
    TOKEN_EXPIRY_BUFFER = 300  # 5 minutes in seconds
    
    def __init__(self, client_id: str, client_secret: str, refresh_token: str):
        """
        Initialize authentication handler
        
        Args:
            client_id: API client ID
            client_secret: API client secret
            refresh_token: Refresh token for generating access tokens
        """
        self.client_id = client_id
        self.client_secret = client_secret
        self.refresh_token = refresh_token
        self._access_token: Optional[str] = None
        self._token_expires_at: Optional[datetime] = None
    
    def generate_token(self) -> str:
        """
        Generate new access token using refresh token
        
        Returns:
            str: Access token
            
        Raises:
            AuthenticationError: If token generation fails
        """
        payload = {
            "client_id": self.client_id,
            "client_secret": self.client_secret,
            "grant_type": "refresh_token",
            "refresh_token": self.refresh_token
        }
        
        headers = {"Content-Type": "application/json"}
        
        try:
            response = requests.post(self.AUTH_URL, json=payload, headers=headers)
            response.raise_for_status()
            
            data = response.json()
            self._access_token = data.get("access_token")
            
            # Set token expiry (assuming 1 hour, adjust based on actual response)
            expires_in = data.get("expires_in", 3600)
            self._token_expires_at = datetime.now() + timedelta(seconds=expires_in)
            
            return self._access_token
            
        except requests.RequestException as e:
            raise AuthenticationError(f"Failed to generate access token: {str(e)}")
    
    def get_token(self) -> str:
        """
        Get valid access token, generating new one if needed
        
        Returns:
            str: Valid access token
        """
        if self._should_refresh_token():
            self.generate_token()
        
        return self._access_token
    
    def _should_refresh_token(self) -> bool:
        """Check if token should be refreshed"""
        if not self._access_token:
            return True
        
        if not self._token_expires_at:
            return True
        
        # Refresh if token expires within buffer time
        time_until_expiry = (self._token_expires_at - datetime.now()).total_seconds()
        return time_until_expiry < self.TOKEN_EXPIRY_BUFFER
    
    def get_headers(self) -> Dict[str, str]:
        """
        Get authorization headers with valid token
        
        Returns:
            Dict containing authorization headers
        """
        token = self.get_token()
        return {
            "Authorization": f"Bearer {token}",
            "Content-Type": "application/json"
        }



"""Settings API module"""

from typing import Dict
from eshopbox.api.base import BaseAPI


class SettingsAPI(BaseAPI):
    """Handle product-related operations"""

    def get_portals(self) -> Dict:
        """Fetch all products with optional filters."""
        url = f"{self.base_url}/api/v1/portal"
        return self._make_request("GET", url)

    def create_workspace(self, data: Dict) -> Dict:
        """Fetch a single product by SKU."""
        url = f"{self.base_url}/api/v1/account"
        return self._make_request("POST", url, json=data)

    def get_all_workspace(self, params: Dict) -> Dict:
        """Create a new product."""
        url = f"{self.base_url}/api/v1/account"
        return self._make_request("GET", url, params=params)

    def get_workspace(self) -> Dict:
        """Update an existing product."""
        url = f"{self.base_url}/api/v1/account/profile"
        return self._make_request("GET", url)

    def update_workspace(self, data: Dict) -> Dict:
        """Update an existing product."""
        url = f"{self.base_url}/api/v1/account/profile"
        return self._make_request("PUT", url, json=data)

    def create_sales_channel(self, data: Dict) -> Dict:
        """Update an existing product."""
        url = f"{self.base_url}/api/v1/channel"
        return self._make_request("POST", url, json=data)

    def update_sales_channel(self, id, data: Dict) -> Dict:
        """Update an existing product."""
        url = f"{self.base_url}/api/v1/channel/{id}"
        return self._make_request("PUT", url, json=data)

    def get_all_sales_channel(self) -> Dict:
        """Update an existing product."""
        url = f"{self.base_url}/api/v1/channel"
        return self._make_request("GET", url)

    def get_sales_channel(self, id: int) -> Dict:
        """Update an existing product."""
        url = f"{self.base_url}/api/v1/channel/{id}"
        return self._make_request("GET", url)

    def create_fc_submission(self, product_data: Dict) -> Dict:
        """Update an existing product."""
        url = f"{self.base_url}/api/v1/subscription"
        return self._make_request("POST", url, json=product_data)

    def get_all_fc_submission(self) -> Dict:
        """Update an existing product."""
        url = f"{self.base_url}/api/v1/warehouse"
        return self._make_request("GET", url)

    def get_fc_submission(self, id: int) -> Dict:
        """Update an existing product."""
        url = f"{self.base_url}/api/platform/v1/client-webhook/{id}"
        return self._make_request("GET", url)

    def update_fc_submission(self, id: int, data: Dict) -> Dict:
        """Update an existing product."""
        url = f"{self.base_url}/api/v1/subscription/{id}"
        return self._make_request("PUT", url, json=data)

    def create_contact(self, data: Dict) -> Dict:
        """Update an existing product."""
        url = f"{self.base_url}/api/v1/contact"
        return self._make_request("POST", url, json=data)

    def get_all_contact(self) -> Dict:
        """Update an existing product."""
        url = f"{self.base_url}/api/v1/contacts"
        return self._make_request("GET", url)

    def get_contact(self, params: Dict = {}) -> Dict:
        """Update an existing product."""
        url = f"{self.base_url}/api/v1/contact"
        return self._make_request("GET", url, params=params)

    def update_contact(self, contactCode: str, data: Dict) -> Dict:
        """Update an existing product."""
        url = f"{self.base_url}/api/v1/contact/{contactCode}"
        return self._make_request("PUT", url, json=data)

    def create_team_member(self, data: Dict) -> Dict:
        """Update an existing product."""
        url = f"{self.base_url}/api/v1/user-account-mapping"
        return self._make_request("POST", url, json=data)

    def update_team_member(self, id, data: Dict) -> Dict:
        """Update an existing product."""
        url = f"{self.base_url}/api/v1/user-account-mapping/{id}"
        return self._make_request("PUT", url, json=data)

    def get_team_member(self, id,) -> Dict:
        """Update an existing product."""
        url = f"{self.base_url}/api/v1/user-account-mapping/{id}"
        return self._make_request("GET", url)

    def get_all_team_member(self) -> Dict:
        """Update an existing product."""
        url = f"{self.base_url}/api/v1/user"
        return self._make_request("GET", url)



import pytest


class TestShipmentsAPI:
    pass

    # def test_create_shipment(self, sdk, mock_token, requests_mock):
    #     requests_mock.post(
    #         "https://test.myeshopbox.com/api/v1/shipments",
    #         json={"shipment_id": "SHIP123"}
    #     )

    #     data = {"order_id": "ORD1"}
    #     result = sdk.shipments.create(data)
    #     assert result["shipment_id"] == "SHIP123"

    # def test_track_shipment(self, sdk, mock_token, requests_mock):
    #     requests_mock.get(
    #         "https://test.myeshopbox.com/api/v1/shipments/SHIP123/track",
    #         json={"status": "in_transit"}
    #     )

    #     tracking = sdk.shipments.track("SHIP123")
    #     assert tracking["status"] == "in_transit"
